@echo OFF
rem ============================================================================================
rem  Function:	Replace the BIOS image on a Novascale Universal R421, R422 or R422-INF motherboard.
rem 
rem  Syntax:	Upgrade.bat RomBiosFile { R421 or R422 or R422INF }
rem 
rem           with RomBiosFile:
rem 
rem 		R421W011 :: BIOS dedicated to "Windows Compute Cluster Server 2003" on Novascale R421
rem 		R422W011 :: BIOS dedicated to "Windows Compute Cluster Server 2003" on Novascale R422/R422-INF
rem 
rem 		R421X011 :: BIOS dedicated to "Redhat/XBAS" on Novascale R421
rem 		R422X011 :: BIOS dedicated to "Redhat/XBAS" on Novascale R422/R422-INF
rem 
rem  Procedure:
rem 		1)-Enter in BIOS setup
rem 		2)-Select "Boot" page and move the "USB Key" at the first position of the list.
rem 		3)-Go to the "Exit" page and "Exit saving changes".
rem 		4)-The server boot from the "USB DOS key".
rem 		5)-Change current directory C:\ to C:\DOS\BIOS
rem 		6)-Execute the command "Upgrade.bat xxxxx"
rem 		7)-When the RomBios image has been upgraded Power Off the server and dismount the Bootable USB Key
rem 		8)-Power On the server
rem 
rem --------------------------------------------------------------------------------------------
rem  History:
rem  20070717	Creation
rem  20070912	New BIOS 1.3c and mode=2 in command phlash16.exe
rem  20071112	Add, save %1 in DMI "Motherboard version string" the BIOS package version.
rem  20071115	Add, new versions R42xy011.ROM (Setup.Advanced.Boot features.POST errors = Disable)
rem ============================================================================================

IF "%1" == "" GOTO FATAL
IF "%2" == "" GOTO FATAL
IF NOT "%3" == "" GOTO FATAL
CD C:\DOS\BIOS

IF NOT EXIST %1.ROM GOTO FATAL2

IF NOT "%2" == "R421" IF NOT "%2" == "R422" IF NOT "%2" == "R422INF" GOTO FATAL
pause

.\chkflash.com %1.ROM
if errorlevel 5 goto FATAL
if errorlevel 4 goto FATAL
if errorlevel 3 goto FATAL
if errorlevel 2 goto FATAL
if errorlevel 1 goto old_flash_utility

:new_flash_utility


echo on
.\phlash16.exe  @%1.txt  %1.ROM
echo off
goto end

:old_flash_utility
echo on
.\phlash.exe /B=linden.bin  @%1.txt  %1.ROM
echo off
goto end


:FATAL2
ECHO.
ECHO Upgrade.bat: The file %1.ROM DOES NOT EXIST.
ECHO.

:FATAL
ECHO.
ECHO FATAL ERROR, Syntax is:  Upgrade.bat  Image { R421 or R422 or R422INF }
ECHO.
ECHO  Image      BIOS ROM dedicated to
ECHO R421W011 = Novascale R421 with WCCS.
ECHO R422W011 = Novascale R422/R422-INF with WCCS
ECHO R421X011 = Novascale R421 with Redhat/XBAS or purchased without OS.
ECHO R422X011 = Novascale R422/R422-INF with Redhat/XBAS or purchased without OS.
ECHO.
ECHO Examples:
ECHO Upgrade.bat R421W011 R421
ECHO Upgrade.bat R422W011 R422
ECHO Upgrade.bat R422W011 R422INF
ECHO Upgrade.bat R421X011 R421
ECHO Upgrade.bat R422X011 R422
ECHO Upgrade.bat R422X011 R422INF
ECHO.
GOTO ENDD

:END

ECHO.
ECHO Upgrade.bat: WARNING:
ECHO.
ECHO Do not forget to execute the following steps after the BIOS is replaced, 
ECHO otherwise the process will be executed again.
ECHO.
ECHO 1-Power Down the server.
ECHO 2-Remove the "Bootable USB Key".
ECHO 3-Power On the server.
ECHO 4-Set default setup options.
ECHO 5-Configure the boot device list.
ECHO 6-Save configuration changes and exit now.
ECHO.   
PAUSE

:ENDD
EXIT
